# CoreX database - neo4j

This package provides an implementation of the CoreX database interface for neo4j.

## Installation
~~~bash
pip install corex-database-neo4j
~~~

## Usage
~~~python
from corex_database_neo4j.handler import Neo4jHandler
handler = Neo4jHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
